==> psiz-0.11.0-py3-none-any.whl: psiz/keras/constraints/center.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 The PsiZ Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Module of custom TensorFlow constraints.

Classes:
    Center:

"""

import tensorflow as tf
from tensorflow.keras import constraints


@tf.keras.utils.register_keras_serializable(package="psiz.keras.constraints")
class Center(constraints.Constraint):
    """Constrains the weights to be zero-centered.

    This constraint can be used to improve the numerical stability of
    an embedding.

    """

    def __init__(self, axis=0):
        """Initialize.

        Args:
            axis (optional): integer, axis along which to reduce
                weights in order to compute mean.

        """
        self.axis = axis

    def __call__(self, w):
        """Call."""
        return w - tf.reduce_mean(w, axis=self.axis, keepdims=True)

    def get_config(self):
        """Return configuration."""
        return {"axis": self.axis}

==> psiz-0.12.4-py3-none-any.whl: psiz/keras/constraints/center.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 The PsiZ Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Module of custom TensorFlow constraints.

Classes:
    Center:

"""


import keras


@keras.saving.register_keras_serializable(package="psiz.keras.constraints")
class Center(keras.constraints.Constraint):
    """Constrains the weights to be zero-centered.

    This constraint can be used to improve the numerical stability of
    an embedding.

    """

    def __init__(self, axis=0):
        """Initialize.

        Args:
            axis (optional): integer, axis along which to reduce
                weights in order to compute mean.

        """
        self.axis = axis

    def __call__(self, w):
        """Call."""
        return w - keras.ops.mean(w, axis=self.axis, keepdims=True)

    def get_config(self):
        """Return configuration."""
        return {"axis": self.axis}
